import sys
import typing

GenericType = typing.TypeVar("GenericType")


def RKS_GEN_available(_ksi, _context, ks, data):
    ''' 

    '''

    pass


def RKS_GEN_bendy_bones(_ksi, _context, ks, data):
    ''' 

    '''

    pass


def RKS_GEN_custom_props(_ksi, _context, ks, data):
    ''' 

    '''

    pass


def RKS_GEN_location(_ksi, _context, ks, data):
    ''' 

    '''

    pass


def RKS_GEN_rotation(_ksi, _context, ks, data):
    ''' 

    '''

    pass


def RKS_GEN_scaling(_ksi, _context, ks, data):
    ''' 

    '''

    pass


def RKS_ITER_selected_bones(ksi, context, ks):
    ''' 

    '''

    pass


def RKS_ITER_selected_item(ksi, context, ks):
    ''' 

    '''

    pass


def RKS_ITER_selected_objects(ksi, context, ks):
    ''' 

    '''

    pass


def RKS_POLL_selected_bones(_ksi, context):
    ''' 

    '''

    pass


def RKS_POLL_selected_items(ksi, context):
    ''' 

    '''

    pass


def RKS_POLL_selected_objects(_ksi, context):
    ''' 

    '''

    pass


def get_transform_generators_base_info(data):
    ''' 

    '''

    pass


def path_add_property(path, prop):
    ''' 

    '''

    pass



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class IDPropertyArray:
    typecode = None
    ''' The type of the data in the array {'f': float, 'd': double, 'i': int, 'b': bool}.'''

    def to_list(self):
        ''' Return the array as a list.

        '''
        pass


class IDPropertyGroup:
    name = None
    ''' The name of this Group.'''

    def clear(self):
        ''' Clear all members from this group.

        '''
        pass

    def get(self, key, default=None):
        ''' Return the value for key, if it exists, else default.

        '''
        pass

    def items(self):
        ''' Iterate through the items in the dict; behaves like dictionary method items.

        '''
        pass

    def keys(self):
        ''' Return the keys associated with this group as a list of strings.

        '''
        pass

    def pop(self, key: str, default: typing.Any):
        ''' Remove an item from the group, returning a Python representation. :raises KeyError: When the item doesn't exist.

        :param key: Name of item to remove.
        :type key: str
        :param default: Value to return when key isn't found, otherwise raise an exception.
        :type default: typing.Any
        '''
        pass

    def to_dict(self):
        ''' Return a purely Python version of the group.

        '''
        pass

    def update(self, other: typing.Union['IDPropertyGroup', typing.Dict]):
        ''' Update key, values.

        :param other: Updates the values in the group with this.
        :type other: typing.Union['IDPropertyGroup', typing.Dict]
        '''
        pass

    def values(self):
        ''' Return the values associated with this group.

        '''
        pass


class IDPropertyGroupIterItems:
    pass


class IDPropertyGroupIterKeys:
    pass


class IDPropertyGroupIterValues:
    pass


class IDPropertyGroupViewItems:
    pass


class IDPropertyGroupViewKeys:
    pass


class IDPropertyGroupViewValues:
    pass



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def stl(override_context: typing.Optional[
        typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        filepath: typing.Union[str, typing.Any] = "",
        filter_glob: typing.Union[str, typing.Any] = "*.stl",
        files: typing.Optional[bpy.types.bpy_prop_collection[
            'bpy.types.OperatorFileListElement']] = None,
        directory: typing.Union[str, typing.Any] = "",
        global_scale: typing.Optional[typing.Any] = 1.0,
        use_scene_unit: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = False,
        use_facet_normal: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        axis_forward: typing.Optional[typing.Any] = 'Y',
        axis_up: typing.Optional[typing.Any] = 'Z'):
    ''' Load STL triangle mesh data :File: `addons/io_mesh_stl/__init__.py\:97 <https://projects.blender.org/blender/blender-addons/addons/io_mesh_stl/__init__.py#L97>`__

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param filepath: File Path, Filepath used for importing the file
    :type filepath: typing.Union[str, typing.Any]
    :param filter_glob: filter_glob
    :type filter_glob: typing.Union[str, typing.Any]
    :param files: File Path
    :type files: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']]
    :param directory: directory
    :type directory: typing.Union[str, typing.Any]
    :param global_scale: Scale
    :type global_scale: typing.Optional[typing.Any]
    :param use_scene_unit: Scene Unit, Apply current scene's unit (as defined by unit scale) to imported data
    :type use_scene_unit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_facet_normal: Facet Normals, Use (import) facet normals (note that this will still give flat shading)
    :type use_facet_normal: typing.Optional[typing.Union[bool, typing.Any]]
    :param axis_forward: Forward
    :type axis_forward: typing.Optional[typing.Any]
    :param axis_up: Up
    :type axis_up: typing.Optional[typing.Any]
    '''

    pass
